@@ -69,7 +69,8 @@ enum
 {
   PROP_0,
 
-  PROP_VIDEO_SINK,
+  PROP_FRAME,
+  PROP_SINK,
   PROP_PLAYER,
   PROP_PAINT_FRAME,
   PROP_PAINT_OVERLAYS,
@@ -278,7 +279,31 @@ content_set_sink (ClutterGstContent   *self,
         }
     }
 
-  g_object_notify (G_OBJECT (self), "video-sink");
+  g_object_notify (G_OBJECT (self), "sink");
+}
+
+static void
+content_set_frame (ClutterGstContent *self,
+                   ClutterGstFrame   *frame)
+{
+  ClutterGstContentPrivate *priv = self->priv;
+
+  if (!frame)
+    {
+      if (priv->current_frame)
+        {
+          g_boxed_free (CLUTTER_GST_TYPE_FRAME, priv->current_frame);
+          priv->current_frame = NULL;
+
+          clutter_content_invalidate (CLUTTER_CONTENT (self));
+        }
+      return;
+    }
+
+  update_frame (self, frame);
+
+  if (CLUTTER_GST_CONTENT_GET_CLASS (self)->has_painting_content (self))
+    clutter_content_invalidate (CLUTTER_CONTENT (self));
 }
 
 static gboolean
@@ -414,7 +439,11 @@ clutter_gst_content_set_property (GObject      *object,
 
   switch (prop_id)
     {
-    case PROP_VIDEO_SINK:
+    case PROP_FRAME:
+      content_set_frame (self, g_value_get_boxed (value));
+      break;
+
+    case PROP_SINK:
       content_set_sink (self, g_value_get_object (value), FALSE);
       break;
 
@@ -447,7 +476,11 @@ clutter_gst_content_get_property (GObject    *object,
 
   switch (prop_id)
     {
-    case PROP_VIDEO_SINK:
+    case PROP_FRAME:
+      g_value_set_boxed (value, priv->current_frame);
+      break;
+
+    case PROP_SINK:
       g_value_set_object (value, priv->sink);
       break;
 
@@ -512,8 +545,15 @@ clutter_gst_content_class_init (ClutterGstContentClass *klass)
                          G_TYPE_OBJECT,
                          G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE);
 
-  props[PROP_VIDEO_SINK] =
-    g_param_spec_object ("video-sink",
+  props[PROP_FRAME] =
+    g_param_spec_boxed ("frame",
+                        "ClutterGst Frame",
+                        "ClutterGst Frame",
+                        CLUTTER_GST_TYPE_FRAME,
+                        G_PARAM_STATIC_STRINGS | G_PARAM_READWRITE);
+
+  props[PROP_SINK] =
+    g_param_spec_object ("sink",
                          "Cogl Video Sink",
                          "Cogl Video Sink",
                          CLUTTER_GST_TYPE_VIDEO_SINK,
@@ -594,7 +634,7 @@ ClutterContent *
 clutter_gst_content_new_with_sink (ClutterGstVideoSink *sink)
 {
   return g_object_new (CLUTTER_GST_TYPE_CONTENT,
-                       "video-sink", sink,
+                       "sink", sink,
                        NULL);
 }
 
@@ -614,6 +654,24 @@ clutter_gst_content_get_frame (ClutterGstContent *self)
   return self->priv->current_frame;
 }
 
+/**
+ * clutter_gst_content_set_frame:
+ * @self: A #ClutterGstContent
+ * @frame: A #ClutterGstFrame
+ *
+ * Set the current frame.
+ *
+ * Since: 3.0
+ */
+void
+clutter_gst_content_set_frame (ClutterGstContent *self,
+                               ClutterGstFrame   *frame)
+{
+  g_return_if_fail (CLUTTER_GST_IS_CONTENT (self));
+
+  content_set_frame (self, frame);
+}
+
 /**
  * clutter_gst_content_get_overlays:
  * @self: A #ClutterGstContent
